@@ -2,7 +2,7 @@
 use core::fmt;
 use std::collections::HashMap;
 use std::hash::{BuildHasherDefault, Hasher};
-use std::net::Ipv4Addr;
+use std::net::IpAddr;
 use log::warn;
 use crate::network::*;
 
@@ -64,6 +64,7 @@ pub enum AttributeFlagsBit {
 #[allow(non_camel_case_types)]
 #[derive(Debug, Primitive, PartialEq, Eq, Hash, Clone)]
 pub enum AttrType {
+    RESERVED = 0,
     ORIGIN = 1,
     AS_PATH = 2,
     NEXT_HOP = 3,
@@ -107,15 +108,15 @@ pub enum AtomicAggregate {
 pub enum Attribute {
     Origin(Origin),
     AsPath(AsPath),
-    NextHop(Ipv4Addr),
+    NextHop(IpAddr),
     MultiExitDiscriminator(u32),
     LocalPreference(u32),
     AtomicAggregate(AtomicAggregate),
-    Aggregator(Asn, Ipv4Addr),
+    Aggregator(Asn, IpAddr),
     Communities(Vec<Community>),
     LargeCommunities(Vec<LargeCommunity>),
-    OriginatorId(Ipv4Addr),
-    Clusters(Vec<Ipv4Addr>),
+    OriginatorId(IpAddr),
+    Clusters(Vec<IpAddr>),
     MpReachableNlri(Nlri),
     MpUnreachableNlri(Nlri),
 }
